from setuptools import setup, find_packages

setup(
    name="pyaws_s3",
    version="1.0.0",
    description="A package for AWS S3 utilities",
    author="Giuseppe Zileni",
    author_email="giuseppe.zileni@gmail,com",
    packages=find_packages(),
    install_requires=[
        "aioboto3==14.3.0",
        "aiobotocore==2.22.0",
        "aiofiles==24.1.0",
        "aiohappyeyeballs==2.6.1",
        "aiohttp==3.11.18",
        "aioitertools==0.12.0",
        "aiosignal==1.3.2",
        "attrs==25.3.0",
        "boto3==1.37.3",
        "botocore==1.37.3",
        "contourpy==1.3.2",
        "cycler==0.12.1",
        "fonttools==4.58.0",
        "fpdf==1.7.2",
        "frozenlist==1.6.0",
        "idna==3.10",
        "jmespath==1.0.1",
        "kiwisolver==1.4.8",
        "matplotlib==3.10.3",
        "multidict==6.4.3",
        "narwhals==1.39.1",
        "numpy==2.2.5",
        "packaging==25.0",
        "pandas==2.2.3",
        "pillow==11.2.1",
        "plotly==6.1.0",
        "propcache==0.3.1",
        "pyparsing==3.2.3",
        "python-dateutil==2.9.0.post0",
        "pytz==2025.2",
        "s3transfer==0.11.3",
        "six==1.17.0",
        "tzdata==2025.2",
        "urllib3==2.4.0",
        "wrapt==1.17.2",
        "yarl==1.20.0"
    ],
    python_requires=">=3.12",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)